@@ -71,18 +71,6 @@
 #ifndef PUNYCODE_H
 # define PUNYCODE_H
 
-# ifndef IDNAPI
-#  if defined LIBIDN_BUILDING && defined HAVE_VISIBILITY && HAVE_VISIBILITY
-#   define IDNAPI __attribute__((__visibility__("default")))
-#  elif defined LIBIDN_BUILDING && defined _MSC_VER && ! defined LIBIDN_STATIC
-#   define IDNAPI __declspec(dllexport)
-#  elif defined _MSC_VER && ! defined LIBIDN_STATIC
-#   define IDNAPI __declspec(dllimport)
-#  else
-#   define IDNAPI
-#  endif
-# endif
-
 #ifdef __cplusplus
 extern "C"
 {
@@ -114,14 +102,14 @@ extern "C"
     PUNYCODE_OVERFLOW = punycode_overflow
   } Punycode_status;
 
-  extern IDNAPI const char *punycode_strerror (Punycode_status rc);
+  const char *punycode_strerror (Punycode_status rc);
 
 /* punycode_uint needs to be unsigned and needs to be */
 /* at least 26 bits wide.                             */
 
   typedef uint32_t punycode_uint;
 
-  extern IDNAPI int punycode_encode (size_t input_length,
+  int punycode_encode (size_t input_length,
 				     const punycode_uint input[],
 				     const unsigned char case_flags[],
 				     size_t * output_length, char output[]);
@@ -181,7 +169,7 @@ extern "C"
         and output might contain garbage.
 */
 
-  extern IDNAPI int punycode_decode (size_t input_length,
+  int punycode_decode (size_t input_length,
 				     const char input[],
 				     size_t * output_length,
 				     punycode_uint output[],
